Installation — pyproject2conda v0.8.0 documentation

Skip to main content
`Ctrl`+`K`

# Installation

## Stable release

Use one of the following to install `pyproject2conda`:

    $ pip install pyproject2conda

or

    $ conda install -c conda-forge pyproject2conda

If using pip, to install with rich and shellingham support, either install them your self, or use:

    $ pip install pyproject2conda[all]

The conda-forge distribution of typer (which `pyproject2conda` uses) installs rich and shellingham by default.

This is the preferred method to install pyproject2conda, as it will always install the most recent stable release.

## From sources

See Contributing for details on installing from source.